@@ -114,12 +114,11 @@ def make_citekey(lastname_first_author, year, title):
     for char in replace_char:
         title = title.replace(char, " ")
     for word in title.split(" "):
-        if word == not_first_word:
+        if word in not_first_word:
             continue
         else:
             title_word = word
             break
-    import ipdb; ipdb.set_trace()
     return f"{lastname_first_author}{year}{title_word}"
 
 
